@@ -7,7 +7,7 @@ with 'HashDataRole::Spec::Basic';
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2024-01-15'; # DATE
 our $DIST = 'HashDataRoles-Standard'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 sub new {
     no strict 'refs'; ## no critic: TestingAndDebugging::ProhibitNoStrict
@@ -103,7 +103,7 @@ sub get_item_at_pos {
     my $oldfhpos = tell $self->{fh};
     seek $self->{fh}, $pos_cache->[$pos], 0;
     chomp(my $line = readline($self->{fh}));
-    my ($key, $value) = split /:/, $line, 2;
+    my ($key, $value) = split /\Q$self->{separator}\E/, $line, 2;
     seek $self->{fh}, $oldfhpos, 0;
     [$key, $value];
 }
@@ -128,7 +128,7 @@ sub get_item_at_key {
     my $oldfhpos = tell $self->{fh};
     seek $self->{fh}, $hash_cache->{$key}, 0;
     chomp(my $line = readline($self->{fh}));
-    my (undef, $value) = split /:/, $line, 2;
+    my (undef, $value) = split /\Q$self->{separator}\E/, $line, 2;
     seek $self->{fh}, $oldfhpos, 0;
     $value;
 }
@@ -175,7 +175,7 @@ HashDataRole::Source::LinesInDATA - Role to access hash data from DATA section,
 
 =head1 VERSION
 
-This document describes version 0.002 of HashDataRole::Source::LinesInDATA (from Perl distribution HashDataRoles-Standard), released on 2024-01-15.
+This document describes version 0.003 of HashDataRole::Source::LinesInDATA (from Perl distribution HashDataRoles-Standard), released on 2024-01-15.
 
 =head1 DESCRIPTION
 
